@@ -657,7 +657,7 @@ ngx_http_uwsgi_handler(ngx_http_request_t *r)
         return NGX_HTTP_INTERNAL_SERVER_ERROR;
     }
 
-    status = ngx_pcalloc(r->pool, sizeof(ngx_http_status_t));
+    status = ngx_palloc(r->pool, sizeof(ngx_http_status_t));
     if (status == NULL) {
         return NGX_HTTP_INTERNAL_SERVER_ERROR;
     }
@@ -1214,19 +1214,6 @@ ngx_http_uwsgi_create_request(ngx_http_request_t *r)
 static ngx_int_t
 ngx_http_uwsgi_reinit_request(ngx_http_request_t *r)
 {
-    ngx_http_status_t  *status;
-
-    status = ngx_http_get_module_ctx(r, ngx_http_uwsgi_module);
-
-    if (status == NULL) {
-        return NGX_OK;
-    }
-
-    status->code = 0;
-    status->count = 0;
-    status->start = NULL;
-    status->end = NULL;
-
     r->upstream->process_header = ngx_http_uwsgi_process_status_line;
     r->state = 0;
 
@@ -1261,10 +1248,6 @@ ngx_http_uwsgi_process_status_line(ngx_http_request_t *r)
         return ngx_http_uwsgi_process_header(r);
     }
 
-    if (u->state && u->state->status == 0) {
-        u->state->status = status->code;
-    }
-
     u->headers_in.status_n = status->code;
 
     len = status->end - status->start;
@@ -1397,16 +1380,38 @@ ngx_http_uwsgi_process_header(ngx_http_request_t *r)
                 ngx_str_set(&u->headers_in.status_line, "200 OK");
             }
 
-            if (u->state && u->state->status == 0) {
-                u->state->status = u->headers_in.status_n;
-            }
-
         done:
 
             if (u->headers_in.status_n == NGX_HTTP_SWITCHING_PROTOCOLS
                 && r->headers_in.upgrade)
             {
                 u->upgrade = 1;
+
+            } else if (u->headers_in.status_n == NGX_HTTP_SWITCHING_PROTOCOLS
+                       || u->headers_in.status_n < NGX_HTTP_CONTINUE)
+            {
+                ngx_log_error(NGX_LOG_ERR, r->connection->log, 0,
+                              "upstream sent unexpected status \"%V\"",
+                              u->headers_in.status_line.len
+                              ? &u->headers_in.status_line
+                              : &u->headers_in.status->value);
+
+                return NGX_HTTP_UPSTREAM_INVALID_HEADER;
+
+            } else if (u->headers_in.status_n < NGX_HTTP_OK) {
+
+                /* ignore unexpected 1xx responses */
+
+                ngx_log_debug0(NGX_LOG_DEBUG_HTTP, r->connection->log, 0,
+                               "http uwsgi 1xx ignored");
+
+                u->process_header = ngx_http_uwsgi_process_status_line;
+
+                if (ngx_http_upstream_clear_headers(r, u) != NGX_OK) {
+                    return NGX_ERROR;
+                }
+
+                return ngx_http_uwsgi_process_status_line(r);
             }
 
             return NGX_OK;
@@ -1573,10 +1578,10 @@ ngx_http_uwsgi_create_loc_conf(ngx_conf_t *cf)
     conf->ssl_conf_commands = NGX_CONF_UNSET_PTR;
 #endif
 
-    /* "uwsgi_cyclic_temp_file" is disabled */
+    /* the hardcoded values */
     conf->upstream.cyclic_temp_file = 0;
-
     conf->upstream.change_buffering = 1;
+    conf->upstream.duplicate_chunked = 0;
 
     ngx_str_set(&conf->upstream.module, "uwsgi");
 
